# pymasker

Pymasker is a python package to generate various masks from the Landsat 8 Quality Assessment band and MODIS land products.

## Installation

The package can be shipped to your computer using pip.

	pip install pymasker

Or just install it with the source code.

	python setup.py install

This package depends on [**numpy**](http://www.numpy.org/). If you want to load the band file directly, [**GDAL**](https://pypi.python.org/pypi/GDAL/) is also in need.

## Use Sample

* [Landsat 8 Quality Assessment band](http://haoliangyu.net/making-masks-with-landsat-8-quality-assessment-band-using-python.html#.VM_7Ny5SWjg)

* [MODIS land products](http://haoliangyu.net/making-masks-from-quality-control-bits-of-modis-land-products-in-python.html#.VM_6Ty5SWjh)